# Documentation

<a href="https://AndrejOrsula.github.io/space_robotics_bench"> <img alt="HTML" src="https://github.com/AndrejOrsula/awesome-space-robotics/assets/22929099/3c8accf7-5acb-4bcd-9553-bf49cc622abe" width="96" height="96"></a>

## Local Preview

We use [mdBook](https://rust-lang.github.io/mdBook) to generate a static site from Markdown files found in the [src](src) directory. To build and preview the site locally, you can [install mdBook](https://rust-lang.github.io/mdBook/guide/installation.html) and run the following command:

```bash
mdbook serve --open
```
